==> icinga2_2.1.1.orig.tar.gz: icinga2-2.1.1/lib/hello/hello.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2014 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "hello/hello.hpp"
#include "base/dynamictype.hpp"
#include "base/logger_fwd.hpp"

using namespace icinga;

REGISTER_TYPE(Hello);

/**
 * The entry point for the Hello application.
 *
 * @returns An exit status.
 */
int Hello::Main(void)
{
	Log(LogInformation, "Hello", "Hello World!");

	return 0;
}

==> icinga2_2.3.8.orig.tar.gz: icinga2-2.3.8/lib/hello/hello.cpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2015 Icinga Development Team (http://www.icinga.org)    *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#include "hello/hello.hpp"
#include "base/logger.hpp"

using namespace icinga;

REGISTER_TYPE(Hello);

/**
 * The entry point for the Hello application.
 *
 * @returns An exit status.
 */
int Hello::Main(void)
{
	Log(LogInformation, "Hello", "Hello World!");

	return 0;
}
